@@ -12,6 +12,7 @@ use Date::Format qw(time2str);
 
 sub options {
     ('l|limit=i'	=> 'limit',
+     'q|quiet'		=> 'quiet',
      'r|revision=s@'	=> 'revspec',
      'x|cross'		=> 'cross',
      'v|verbose'	=> 'verbose');
@@ -68,7 +69,7 @@ sub run {
     print $sep;
     _get_logs ($target->root, $self->{limit} || -1, $target->{path}, $fromrev, $torev,
 	       $self->{verbose}, $self->{cross},
-	       sub {_show_log (@_, $sep, undef, 0, $print_rev, 1, 0)} );
+	       sub {_show_log (@_, $sep, undef, 0, $print_rev, 1, 0, $self->{quiet})} );
     return;
 }
 
@@ -123,15 +124,23 @@ $chg->[$SVN::Fs::PathChange::delete] = 'D';
 $chg->[$SVN::Fs::PathChange::replace] = 'R';
 
 sub _show_log {
-    my ($rev, $root, $paths, $props, $sep, $output, $indent, $print_rev, $use_localtime, $verbatim) = @_;
+    my ($rev, $root, $paths, $props, $sep, $output, $indent, $print_rev, $use_localtime,
+	$verbatim, $quiet) = @_;
     $output ||= select;
-    my ($author, $date, $message) = @{$props}{qw/svn:author svn:date svn:log/};
+    $indent = (' ' x $indent);
+    my ($author, $date, $message);
+    if ($quiet) {
+      ($author, $date) = @{$props}{qw/svn:author svn:date/};
+      $message = $sep;
+    } else {
+      ($author, $date, $message) = @{$props}{qw/svn:author svn:date svn:log/};
+	$message = ($indent ? '' : "\n")."$message\n$sep";
+    }
     if (defined $use_localtime) {
 	no warnings 'uninitialized';
 	local $^W; # shut off uninitialized warnings in Time::Local
 	$date = time2str("%Y-%m-%d %T %z", str2time ($date));
     }
-    $indent = (' ' x $indent);
     $author = loc('(no author)') if !defined($author) or !length($author);
     $output->print ($indent.$print_rev->($rev).":  $author | $date\n") unless $verbatim;
     if ($paths) {
@@ -153,7 +162,6 @@ sub _show_log {
 		    )."\n");
 	}
     }
-    $message = ($indent ? '' : "\n")."$message\n$sep";
 #    $message =~ s/\n\n+/\n/mg;
     $message =~ s/^/$indent/mg if $indent and !$verbatim;
     require Encode;
@@ -193,12 +201,14 @@ SVK::Command::Log - Show log messages for revisions
 
                           "HEAD"       latest in repository
                           NUMBER       revision number
+                          NUMBER@      interpret as remote revision number
                           NUM1:NUM2    revision range
 
                           Unlike other commands,  negative NUMBER has no
                           meaning.
 
  -l [--limit] REV       : stop after displaying REV revisions
+ -q [--quiet]           : Don't display the actual log message itself
  -x [--cross]           : track revisions copied from elsewhere
  -v [--verbose]         : print extra information
 
